@@ -115,6 +115,7 @@
 #' @seealso Describe the shape of a tree topology, independent of leaf labels:
 #' [`TreeShape()`]
 #' @family tree generation functions
+#' @family 'TreeNumber' utilities
 #' @name TreeNumber
 #
 
@@ -124,7 +125,8 @@
 #' which comprises a numeric vector, whose elements represent successive
 #' nine-digit chunks of the decimal integer corresponding to the tree topology
 #' (in big endian order).  The `TreeNumber` object has attributes
-#' `nTip` and `tip.label`.
+#' `nTip` and `tip.label`.  If `x` is a list of trees or a `multiPhylo` object,
+#' then `as.TreeNumber()` returns a corresponding list of `TreeNumber` objects.
 #' @export
 as.TreeNumber <- function(x, ...) UseMethod("as.TreeNumber")
 
@@ -363,6 +365,19 @@ as.integer64.TreeNumber <- function(x, ...) {
   structure(x[1], class = "integer64")
 }
 
+#' Is an object a `TreeNumber` object?
+#' 
+#' @param x R object.
+#' @return `is.TreeNumber()` returns a logical vector of length one specifying
+#' whether `x` inherits the class `"TreeNumber"`.
+#' @template MRS
+#' @examples
+#' is.TreeNumber(FALSE) # FALSE 
+#' is.TreeNumber(as.TreeNumber(BalancedTree(5))) # TRUE
+#' @family 'TreeNumber' utilities
+#' @export
+is.TreeNumber <- function(x) inherits(x, "TreeNumber")
+
 #' Print `TreeNumber` object
 #'
 #' S3 method for objects of class `TreeNumber`.
@@ -370,6 +385,7 @@ as.integer64.TreeNumber <- function(x, ...) {
 #' @param x Object of class `TreeNumber`.
 #' @param \dots Additional arguments for consistency with S3 method (unused).
 #'
+#' @family 'TreeNumber' utilities
 #' @export
 print.TreeNumber <- function(x, ...) {
   nTip <- attr(x, "nTip")
